[llvm] r248283 - Fix a typo.

Adrian Prantl via llvm-commits llvm-commits at lists.llvm.org
Tue Sep 22 08:31:15 PDT 2015


Author: adrian
Date: Tue Sep 22 10:31:14 2015
New Revision: 248283

URL: http://llvm.org/viewvc/llvm-project?rev=248283&view=rev
Log:
Fix a typo.

Modified:
    llvm/trunk/tools/dsymutil/DwarfLinker.cpp

Modified: llvm/trunk/tools/dsymutil/DwarfLinker.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/tools/dsymutil/DwarfLinker.cpp?rev=248283&r1=248282&r2=248283&view=diff
==============================================================================
--- llvm/trunk/tools/dsymutil/DwarfLinker.cpp (original)
+++ llvm/trunk/tools/dsymutil/DwarfLinker.cpp Tue Sep 22 10:31:14 2015
@@ -1186,7 +1186,7 @@ private:
 
   /// \brief Mark the passed DIE as well as all the ones it depends on
   /// as kept.
-  void keepDIEAndDenpendencies(RelocationManager &RelocMgr,
+  void keepDIEAndDependencies(RelocationManager &RelocMgr,
                                const DWARFDebugInfoEntryMinimal &DIE,
                                CompileUnit::DIEInfo &MyInfo,
                                const DebugMapObject &DMO, CompileUnit &CU,
@@ -2067,7 +2067,7 @@ unsigned DwarfLinker::shouldKeepDIE(Relo
 /// back to lookForDIEsToKeep while adding TF_DependencyWalk to the
 /// TraversalFlags to inform it that it's not doing the primary DIE
 /// tree walk.
-void DwarfLinker::keepDIEAndDenpendencies(RelocationManager &RelocMgr,
+void DwarfLinker::keepDIEAndDependencies(RelocationManager &RelocMgr,
                                           const DWARFDebugInfoEntryMinimal &Die,
                                           CompileUnit::DIEInfo &MyInfo,
                                           const DebugMapObject &DMO,
@@ -2151,7 +2151,7 @@ void DwarfLinker::lookForDIEsToKeep(Relo
   if ((Flags & TF_DependencyWalk) && AlreadyKept)
     return;
 
   // We must not call shouldKeepDIE while called from keepDIEAndDenpendencies,
   // because it would screw up the relocation finding logic.
   if (!(Flags & TF_DependencyWalk))
     Flags = shouldKeepDIE(RelocMgr, Die, CU, MyInfo, Flags);
@@ -2159,7 +2159,7 @@ void DwarfLinker::lookForDIEsToKeep(Relo
   // If it is a newly kept DIE mark it as well as all its dependencies as kept.
   if (!AlreadyKept && (Flags & TF_Keep)) {
     bool UseOdr = (Flags & TF_DependencyWalk) ? (Flags & TF_ODR) : CU.hasODR();
-    keepDIEAndDenpendencies(RelocMgr, Die, MyInfo, DMO, CU, UseOdr);
+    keepDIEAndDependencies(RelocMgr, Die, MyInfo, DMO, CU, UseOdr);
   }
   // The TF_ParentWalk flag tells us that we are currently walking up
   // the parent chain of a required DIE, and we don't want to mark all
@@ -2151,7 +2151,7 @@ void DwarfLinker::lookForDIEsToKeep(Relo
     return;
 
-  // We must not call shouldKeepDIE while called from keepDIEAndDenpendencies,
+  // We must not call shouldKeepDIE while called from keepDIEAndDependencies,
   // because it would screw up the relocation finding logic.
   if (!(Flags & TF_DependencyWalk))




More information about the llvm-commits mailing list